Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(445)

Unified Diff: chrome/browser/app_controller_mac.mm

Issue 25603004: Leave apps running on Windows and Linux when quitting Chrome from the wrench menu. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/app_controller_mac.mm
diff --git a/chrome/browser/app_controller_mac.mm b/chrome/browser/app_controller_mac.mm
index 34736e6251be73809fade4cc03caf67b8cdb177b..f2832dd5b669a6bf7027fc59c1c1d762118355f0 100644
--- a/chrome/browser/app_controller_mac.mm
+++ b/chrome/browser/app_controller_mac.mm
@@ -359,15 +359,12 @@ class AppControllerProfileObserver : public ProfileInfoCacheObserver {
size_t num_browsers = chrome::GetTotalBrowserCount();
- // Initiate a shutdown (via chrome::CloseAllBrowsers()) if we aren't
- // already shutting down.
- if (!browser_shutdown::IsTryingToQuit()) {
- content::NotificationService::current()->Notify(
- chrome::NOTIFICATION_CLOSE_ALL_BROWSERS_REQUEST,
- content::NotificationService::AllSources(),
- content::NotificationService::NoDetails());
- chrome::CloseAllBrowsers();
- }
+ // Initiate a shutdown (via chrome::CloseAllBrowsersAndQuit()).
+ content::NotificationService::current()->Notify(
+ chrome::NOTIFICATION_CLOSE_ALL_BROWSERS_REQUEST,
+ content::NotificationService::AllSources(),
+ content::NotificationService::NoDetails());
+ chrome::CloseAllBrowsersAndQuit();
return num_browsers == 0 ? YES : NO;
}

Powered by Google App Engine
This is Rietveld 408576698